/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	bspboard.h	Defines GPIO to be configured by the BSP
				The definitions allows to use the BSP functions: bspOutput(), bspToggleOutput(), bspInput()

	When		Who	What
	10/06/17	ac	Creation
	13/05/20	ac	Add BSP_xxxn_ATTR

----------------------------------------------------------------------
*/

#if ! defined AABSPBOARD_H_
#define AABSPBOARD_H_
//--------------------------------------------------------------------------------
//	Fast access to some I/O pins
//	Don't change theses macros

#define	BSP_IO_GPIO(portNumber)				((GPIO_TypeDef *)(GPIOA_BASE + (GPIOB_BASE-GPIOA_BASE)*(portNumber)))
#define	BSP_MAKE_IO(portNumber, pinNumber)	((portNumber) << 4 | (pinNumber))


//--------------------------------------------------------------------------------
//	Here the user defines the pins that should be configured by bspBoardInit() in bspboard.c

// For each I/O an optional attribute can be added. Example:
// #define	BSP_BUTTON0_ATTR			(AA_GPIO_PULL_UP)
// #define	BSP_OUTPUT0_ATTR			(AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_UP)

// Theses pins are for LQFP144 NUCLEO-stm32F429ZI board
#if (defined STM32F429xx)

// Green LED
#define BSP_LED0_PORT_NUMBER		(1)	// 1 is port B
#define BSP_LED0_PIN_NUMBER			(0)
#define	BSP_LED0					(BSP_MAKE_IO(BSP_LED0_PORT_NUMBER, BSP_LED0_PIN_NUMBER))
#define	BSP_LED0_ON					(1)
#define	BSP_LED0_OFF				(0)

// Blue LED
#define BSP_LED1_PORT_NUMBER		(1)
#define BSP_LED1_PIN_NUMBER			(7)
#define	BSP_LED1					(BSP_MAKE_IO(BSP_LED1_PORT_NUMBER, BSP_LED1_PIN_NUMBER))
#define	BSP_LED1_ON					(1)
#define	BSP_LED1_OFF				(0)

// Red LED
#define BSP_LED2_PORT_NUMBER		(1)
#define BSP_LED2_PIN_NUMBER			(14)
#define	BSP_LED2					(BSP_MAKE_IO(BSP_LED2_PORT_NUMBER, BSP_LED2_PIN_NUMBER))
#define	BSP_LED2_ON					(1)
#define	BSP_LED2_OFF				(0)

// User button
#define BSP_BUTTON0_PORT_NUMBER		(2)
#define BSP_BUTTON0_PIN_NUMBER		(13)
#define	BSP_BUTTON0					(BSP_MAKE_IO(BSP_BUTTON0_PORT_NUMBER, BSP_BUTTON0_PIN_NUMBER))
#define	BSP_BUTTON0_PRESSED			(1)

// User defined pins
// Debug pin 0
#define	BSP_OUTPUT0_PORT_NUMBER		(6)	// 6 is port G
#define	BSP_OUTPUT0_PIN_NUMBER		(0)
#define	BSP_OUTPUT0					(BSP_MAKE_IO(BSP_OUTPUT0_PORT_NUMBER, BSP_OUTPUT0_PIN_NUMBER))

// Debug pin 1
#define	BSP_OUTPUT1_PORT_NUMBER		(6)	// Port G
#define	BSP_OUTPUT1_PIN_NUMBER		(3)
#define	BSP_OUTPUT1					(BSP_MAKE_IO(BSP_OUTPUT1_PORT_NUMBER, BSP_OUTPUT1_PIN_NUMBER))

#endif	// STM32F429xx

// Theses pins are for LQFP64 NUCLEO-STM32F446RE board
#if (defined STM32F446xx)

// Green LED
#define BSP_LED0_PORT_NUMBER		(0)	// 0 is port A
#define BSP_LED0_PIN_NUMBER			(5)
#define	BSP_LED0					(BSP_MAKE_IO(BSP_LED0_PORT_NUMBER, BSP_LED0_PIN_NUMBER))
#define	BSP_LED0_ON					(1)
#define	BSP_LED0_OFF				(0)

// User button
#define BSP_BUTTON0_PORT_NUMBER		(2)
#define BSP_BUTTON0_PIN_NUMBER		(13)
#define	BSP_BUTTON0					(BSP_MAKE_IO(BSP_BUTTON0_PORT_NUMBER, BSP_BUTTON0_PIN_NUMBER))
#define	BSP_BUTTON0_PRESSED			(0)

// User defined pins
// Debug pin 0
#define	BSP_OUTPUT0_PORT_NUMBER		(2)
#define	BSP_OUTPUT0_PIN_NUMBER		(3)
#define	BSP_OUTPUT0					(BSP_MAKE_IO(BSP_OUTPUT0_PORT_NUMBER, BSP_OUTPUT0_PIN_NUMBER))

// Debug pin 1
#define	BSP_OUTPUT1_PORT_NUMBER		(1)
#define	BSP_OUTPUT1_PIN_NUMBER		(8)
#define	BSP_OUTPUT1					(BSP_MAKE_IO(BSP_OUTPUT1_PORT_NUMBER, BSP_OUTPUT1_PIN_NUMBER))

#endif	// STM32F446xx

// Theses pins are for STM32F411CE Black Pill
#if (defined STM32F411xE)

// Blue LED
#define BSP_LED0_PORT_NUMBER		(2)	// 0 is port A
#define BSP_LED0_PIN_NUMBER			(13)
#define	BSP_LED0					(BSP_MAKE_IO(BSP_LED0_PORT_NUMBER, BSP_LED0_PIN_NUMBER))
#define	BSP_LED0_ON					(0)
#define	BSP_LED0_OFF				(1)

// User KEY
#define BSP_BUTTON0_PORT_NUMBER		(0)
#define BSP_BUTTON0_PIN_NUMBER		(0)
#define	BSP_BUTTON0					(BSP_MAKE_IO(BSP_BUTTON0_PORT_NUMBER, BSP_BUTTON0_PIN_NUMBER))
#define	BSP_BUTTON0_ATTR			(AA_GPIO_PULL_UP)	// There is no pull up on the board
#define	BSP_BUTTON0_PRESSED			(0)

// User defined pins
// Debug pin 0
#define	BSP_OUTPUT0_PORT_NUMBER		(1)
#define	BSP_OUTPUT0_PIN_NUMBER		(12)
#define	BSP_OUTPUT0					(BSP_MAKE_IO(BSP_OUTPUT0_PORT_NUMBER, BSP_OUTPUT0_PIN_NUMBER))

// Debug pin 1
//#define	BSP_OUTPUT1_PORT_NUMBER		(1)
//#define	BSP_OUTPUT1_PIN_NUMBER		(8)
//#define	BSP_OUTPUT1					(BSP_MAKE_IO(BSP_OUTPUT1_PORT_NUMBER, BSP_OUTPUT1_PIN_NUMBER))
//#define	BSP_OUTPUT1_ATTR			(0)

#endif	// STM32F411xE

//--------------------------------------------------------------------------------
#endif // AABSPBOARD_H_
