
/*--------------------------------------------------------------------------
/*
 * Memory Spaces Definitions.
 *
 * Update for a specific board. 
 *   FLASH.ORIGIN : starting address of flash
 *   FLASH.LENGTH : length of flash
 *   RAM.ORIGIN   : starting address of main RAM
 *   RAM.LENGTH   : length of main RAM
 *
 * The values below can be addressed in linker scripts
 * using functions like 'ORIGIN(RAM)' or 'LENGTH(RAM)'.
 */

/* Memory definitions for  STM32F401/411xx
 * Adjust your amount of RAM and FLASH:
 *
 *				FLASH	RAM
 * F401xB		128K	64K
 * F401xC		256K	64K		* Old MiniF401 / WeAct Studio
 * F401xD		384K	96K
 * F401xE		512K	96K		* New MiniF401 / WeAct Studio
 *
 * F411xC		256K	128K
 * F411xE		512K	128K	* MiniF411 / WeAct Studio "Black Pill"
 *
 * No CCMRAM, no BKPRAM
 * Can't execute code from SRAM
 * Only 1 FLASH bank
 */

MEMORY
{
	FLASH         (rx) : ORIGIN = 0x08000000, LENGTH = 512K
	FLASHB2       (rx) : ORIGIN = 0x00000000, LENGTH = 0
	RAM           (rw) : ORIGIN = 0x20000000, LENGTH = 96K
	CCMRAM        (rw) : ORIGIN = 0x10000000, LENGTH = 0
	BKPRAM        (rw) : ORIGIN = 0x40024000, LENGTH = 0

	EXTMEMB0      (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB1      (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB2      (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB3      (rx) : ORIGIN = 0x00000000, LENGTH = 0
}

INCLUDE ../sections.ld