/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	i2cC24xx.c	Master I2C library for 24Cxx EEPROM
				Allows to use 24C series of EEPROM with up to 2048 bytes

	When		Who	What
	09/04/18	ac	Creation

----------------------------------------------------------------------
*/
/*
----------------------------------------------------------------------
	Copyright (c) 2013-2023 Alain Chebrou - AdAstra-Soft . com
	All rights reserved.

	This file is part of the AdAstra Real Time Kernel distribution.

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright
	  notice, this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright
	  notice, this list of conditions and the following disclaimer in the
	  documentation and/or other materials provided with the distribution.

	- Neither the name of the copyright holder nor the
	  names of its contributors may be used to endorse or promote products
	  derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
	DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------------------------------------------------
*/

#if ! defined EE24CXX_H_
#define EE24CXX_H_
//----------------------------------------------------------------------
#include	"i2cbasic.h"

typedef enum
{
	EE24C01			= 0,	// 128  bytes
	EE24C02			= 1,	// 256  bytes
	EE24C04			= 2,	// 512  bytes
	EE24C08			= 3,	// 2014 bytes
	EE24C16			= 4		// 2048 bytes

} ee24cType_t ;

//----------------------------------------------------------------------
extern	const uint32_t	ee24cPageDesc [5] ;

#define	EE24C_PAGEMASK(type)		((ee24cPageDesc[type] >> 16) & 0x00FFu)
#define	EE24C_PAGECOUNT(type)		((ee24cPageDesc[type] >> 8) & 0x00FFu)
#define	EE24C_PAGESIZE(type)		(ee24cPageDesc[type] & 0x00FFu)

//----------------------------------------------------------------------
//	EEPROM descriptor and functions

typedef struct
{
	const i2cDesc_t		* pI2cDesc ;
	i2cHandle_t			i2cHdl ;
	ee24cType_t			eeType ;
	uint8_t				i2cAddress ;	// 7 bits left aligned
	uint8_t				header [2] ;

} ee24cDesc_t ;

#ifdef __cplusplus
extern "C" {
#endif

i2cStatus_t	ee24cInit		(ee24cDesc_t * pDesc, ee24cType_t type, uint32_t i2cAddress) ;
i2cStatus_t	ee24cWrite		(ee24cDesc_t * pDesc, uint32_t offset, uint8_t * pBuffer, uint32_t count) ;
i2cStatus_t	ee24cRead		(ee24cDesc_t * pDesc, uint32_t offset, uint8_t * pBuffer, uint32_t count) ;

#ifdef __cplusplus
}
#endif

//----------------------------------------------------------------------
#endif	// EE24CXX_H_
