/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	i2cdescF4.c		STM32F411 I2C descriptors for i2cbasic.c

	When		Who	What
	01/03/18	ac	Creation

----------------------------------------------------------------------
*/
/*
----------------------------------------------------------------------
	Copyright (c) 2013-2023 Alain Chebrou - AdAstra-Soft . com
	All rights reserved.

	This file is part of the AdAstra Real Time Kernel distribution.

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright
	  notice, this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright
	  notice, this list of conditions and the following disclaimer in the
	  documentation and/or other materials provided with the distribution.

	- Neither the name of the copyright holder nor the
	  names of its contributors may be used to endorse or promote products
	  derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND ANY
	EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
	DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------------------------------------------------
*/

#if ! defined I2CF4xx_H_
#define I2CF4xx_H_
//------------------------------------------------------------------------------

/*
I2C pin out for STM32F411CE

I2C1	4	PB7		PB6
		4	PB9		PB8

I2C2	4	(PB11)	PB10
		9	PB3
		9	PB9

I2C3	4	PC9		PA8
		9	PB4
		9	PB8
PB11 available only on UFBGA100
*/

//	These configurations can be modified and augmented by the user to comply with the application

STATIC	const i2cDesc_t		i2cArray [] =
{
	#if (WITH_I2C_1 == 1)
	{
		1,						// Descriptor identifier
		RCC_APB1RSTR_I2C1RST_Pos,
		RCC_APB1ENR_I2C1EN_Pos,	// periph enable bit position
		{	AA_GPIO_PORTB,		// port Sda
			7,					// pin  Sda
			AA_GPIO_AF_4,		// af   Sda
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		{	AA_GPIO_PORTB,		// Port Scl
			6,					// pin  Scl
			AA_GPIO_AF_4,		// af   Scl
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		I2C1,					// I2C_TypeDef*

		I2C1_EV_IRQn,
		I2C1_ER_IRQn,
		I2C_INT_PRIORITY,
	},
	#endif	// WITH_I2C_1

	#if (WITH_I2C_2 == 1)
	{
		2,						// Descriptor identifier
		RCC_APB1RSTR_I2C2RST_Pos,
		RCC_APB1ENR_I2C2EN_Pos,	// periphPos ;
		{	AA_GPIO_PORTB,		// port Sda ;
			9,					// pin  Sda;
			AA_GPIO_AF_9,		// af   Sda ;
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		{	AA_GPIO_PORTB,		// port Scl;
			10,					// pin  Scl ;
			AA_GPIO_AF_4,		// af   Scl ;
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		I2C2,					// I2C_TypeDef ;

		I2C2_EV_IRQn,
		I2C2_ER_IRQn,
		I2C_INT_PRIORITY,
	},
	#endif	// WITH_I2C_2

	#if (WITH_I2C_3 == 1)
	{
		3,						// Descriptor identifier
		RCC_APB1RSTR_I2C3RST_Pos,
		RCC_APB1ENR_I2C3EN_Pos,	// periphPos ;
		{	AA_GPIO_PORTC,		// port Sda ;
			9,					// pin  Sda;
			AA_GPIO_AF_4,		// af   Sda ;
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		{	AA_GPIO_PORTA,		// Port Scl;
			8,					// pin  Scl ;
			AA_GPIO_AF_4,		// af   Scl ;
			AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_HIGH | AA_GPIO_OPEN_DRAIN | AA_GPIO_PULL_NO,
		},
		I2C3,					// I2C_TypeDef ;

		I2C3_EV_IRQn,
		I2C3_ER_IRQn,
		I2C_INT_PRIORITY,
	},
	#endif	// WITH_I2C_3

	// You can insert here other descriptors for alternate gpio pins
	// Choose an unique descriptor identifier for every descriptor
} ;

//------------------------------------------------------------------------------
#endif	// I2CF4xx_H_
