/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	timF429ZI.c		STM32F4 LQFP144 Timer descriptors for timbasic.c

	When		Who	What
	08/03/18	ac	Creation

----------------------------------------------------------------------
*/
/*
----------------------------------------------------------------------
	Copyright (c) 2013-2023 Alain Chebrou - AdAstra-Soft . com
	All rights reserved.

	This file is part of the AdAstra Real Time Kernel distribution.

	Redistribution and use in source and binary forms, with or without
	modification, are permitted provided that the following conditions are met:

	- Redistributions of source code must retain the above copyright
	  notice, this list of conditions and the following disclaimer.

	- Redistributions in binary form must reproduce the above copyright
	  notice, this list of conditions and the following disclaimer in the
	  documentation and/or other materials provided with the distribution.

	- Neither the name of the copyright holder nor the
	  names of its contributors may be used to endorse or promote products
	  derived from this software without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
	DISCLAIMED. IN NO EVENT SHALL THE REGENTS AND CONTRIBUTORS BE LIABLE FOR ANY
	DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
	ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
----------------------------------------------------------------------
*/

#if ! defined timF4xx_H_
#define timF4xx_H_
//------------------------------------------------------------------------------
/*
TIM		AF	CH1		CH1N	CH2		CH2N	CH3		CH3N	CH4		BKIN	ETR
--------------------------------------------------------------------------------
TIM1	1	PA8		PA7		PA9		PB0		PA10	PB1		PA11	PA6		PA12
			PE9		PE8		PE11	PE10	PE13	PE12	PE14	PE15	PE7
					PB13			PB14			PB15			PB12

TIM2	1	PA0				PA1				PA2				PA3				PA0
			PA5				PB3				PB10			PB11			PA5
			PA15															PA15

TIM3	2	PA6				PA7
			PB4				PB5				PB0				PB1
			PC6				PC7				PC8				PC9				PD2

TIM4	2	PB6				PB7				PB8				PB9				PE0
			PD12			PD13			PD14			PD15	

TIM5	2	PA0				PA1				PA2				PA3
			PH10			PH11			PH12			PI0

TIM6		No I/O

TIM7		No I/O

TIM8	3	PC6		PA5		PC7		PB0		PC8		PB1		PC9		PA6		PA0
			PI5		PA7		PI6		PB14	PI7		PB15	PI2		PI4		PI3
					PH13			PH14			PH15

TIM9	3	PA2				PA3
			PE5				PE6

TIM10	3	PB8
			PF6

TIM11	3	PB9
			PF7

TIM12	9	PB14			PB15
			PH6				PH9

TIM13	9	PA6
			PF8

TIM14	9	PA7
			PF9

Master mode TRGO available on TIM1 to TIM8
NUCLEO-F429ZI: TIM2 and TIM3 are mapped on Arduino connectors
*/

//------------------------------------------------------------------------------
// In this descriptor array example, at least one descriptors for each timer configuration

// Some timer manage more than 1 interrupt vector: TIM1 and TIM8
// The descriptor describe only 1 interrupt.
// If you need more than 1 interrupt vector, configure the other interrupts from your application code

const	timDesc_t	timDescArray [] =
{
	#if (WITH_TIM_1 == 1)
	{
		1,									// Descriptor identifier
		1,									// Timer number 1..n
		RCC_APB2RSTR_TIM1RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB2ENR_TIM1EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_ADVT | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK | TIM_CAP_COMP_OUT, 	// Capabilities flags
		TIM1,								// Pointer to TIM registers
		TIM1_UP_TIM10_IRQn,
		{
			{	'A',	8,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'A',	9,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'A',	10,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'A',	11,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	'A',	7,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1N
			{	'B',	0,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2N
			{	'B',	1,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3N
			{	'A',	12,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// ETR
			{	'A',	6,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// BKIN
		},
	},
	#endif	// WITH_TIM1

	#if (WITH_TIM_2 == 1)
	{
		2,									// Descriptor identifier
		2,									// Timer number 1..n
		RCC_APB1RSTR_TIM2RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM2EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT1 | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK | TIM_CAP_32_BITS, 	// Capabilities flags
		TIM2,								// Pointer to TIM registers
		TIM2_IRQn,
		{
			{	'A',	0,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'B',	3,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'B',	10,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'A',	3,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch3N
			{	'A',	0,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// ETR
			{	0,		0,	AA_GPIO_AF_1,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM2

	#if (WITH_TIM_3 == 1)
	{
		3,									// Descriptor identifier
		3,									// Timer number 1..n
		RCC_APB1RSTR_TIM3RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM3EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT1 | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK, 	// Capabilities flags
		TIM3,								// Pointer to TIM registers
		TIM3_IRQn,
		{
			{	'C',	6,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'C',	7,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'C',	8,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'C',	9,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch3N
			{	'D',	2,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// ETR
			{	0,		0,	AA_GPIO_AF_2,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM3
	
	#if (WITH_TIM_4 == 1)
	{
		4,									// Descriptor identifier
		4,									// Timer number 1..n
		RCC_APB1RSTR_TIM4RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM4EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT1 | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK, 	// Capabilities flags
		TIM4,								// Pointer to TIM registers
		TIM4_IRQn,
		{
			{	'B',	6,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'B',	7,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'B',	8,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'B',	9,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch3N
			{	'E',	0,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// ETR
			{	0,		0,	AA_GPIO_AF_2,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM4
	
	#if (WITH_TIM_5 == 1)
	{
		5,									// Descriptor identifier
		5,									// Timer number 1..n
		RCC_APB1RSTR_TIM5RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM5EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT1 | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK | TIM_CAP_32_BITS, 	// Capabilities flags
		TIM5,								// Pointer to TIM registers
		TIM5_IRQn,
		{
			{	'A',	0,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'A',	1,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'A',	2,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'A',	3,	AA_GPIO_AF_2,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_2,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_2,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM5

	#if (WITH_TIM_6 == 1)
	{
		6,									// Descriptor identifier
		6,									// Timer number 1..n
		RCC_APB1RSTR_TIM6RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM6EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_BASIC | TIM_CAP_DMA, 	// Capabilities flags
		TIM6,								// Pointer to TIM registers
		TIM6_DAC_IRQn,
		{
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch1
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_1,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM6

	#if (WITH_TIM_7 == 1)
	{
		7,									// Descriptor identifier
		7,									// Timer number 1..n
		RCC_APB1RSTR_TIM7RST_Pos,			/ RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM7EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_BASIC | TIM_CAP_DMA, 	// Capabilities flags
		TIM7,								// Pointer to TIM registers
		TIM7_IRQn,
		{
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch1
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_1,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_1,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM7

	#if (WITH_TIM_8 == 1)
	{
		8,									// Descriptor identifier
		8,									// Timer number 1..n
		RCC_APB2RSTR_TIM8RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB2ENR_TIM8EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_ADVT | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_BREAK | TIM_CAP_COMP_OUT, 	// Capabilities flags
		TIM8,								// Pointer to TIM registers
		TIM8_UP_TIM13_IRQn,
		{
			{	'C',	6,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'A',	5,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	'C',	7,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3
			{	'B',	0,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch4
			{	'C',	8,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1N
			{	'B',	1,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2N
			{	'C',	9,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch3N
			{	'I',	3,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// ETR
			{	'I',	4,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// BKIN
		},
	},
	#endif	// WITH_TIM8

	#if (WITH_TIM_9 == 1)
	{
		9,									// Descriptor identifier
		9,									// Timer number 1..n
		RCC_APB2RSTR_TIM9RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB2ENR_TIM9EN_Pos,				// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1_2, 	// Capabilities flags
		TIM9,								// Pointer to TIM registers
		TIM1_BRK_TIM9_IRQn,
		{
			{	'A',	2,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'A',	3,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_3,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM9

	#if (WITH_TIM_10 == 1)
	{
		10,									// Descriptor identifier
		10,									// Timer number 1..n
		RCC_APB2RSTR_TIM10RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB2ENR_TIM10EN_Pos,			// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1, // Capabilities flags
		TIM10,								// Pointer to TIM registers
		TIM1_UP_TIM10_IRQn,
		{
			{	'F',	6,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_3,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM10

	#if (WITH_TIM_11 == 1)
	{
		11,									// Descriptor identifier
		11,									// Timer number 1..n
		RCC_APB2RSTR_TIM11RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB2ENR_TIM11EN_Pos,			// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1, // Capabilities flags
		TIM11,								// Pointer to TIM registers
		TIM1_TRG_COM_TIM11_IRQn,
		{
			{	'B',	9,	AA_GPIO_AF_3,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_3,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_3,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM11

	#if (WITH_TIM_12 == 1)
	{
		12,									// Descriptor identifier
		12,									// Timer number 1..n
		RCC_APB1RSTR_TIM12RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM12EN_Pos,			// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1_2, 	// Capabilities flags
		TIM12,								// Pointer to TIM registers
		TIM8_BRK_TIM12_IRQn,
		{
			{	'B',	14,	AA_GPIO_AF_9,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	'B',	15,	AA_GPIO_AF_9,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch2
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_9,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM12

	#if (WITH_TIM_13 == 1)
	{
		13,								// Descriptor identifier
		13,								// Timer number 1..n
		RCC_APB1RSTR_TIM13RST_Pos,		// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM13EN_Pos,		// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1, 	// Capabilities flags
		TIM13,							// Pointer to TIM registers
		TIM8_UP_TIM13_IRQn,
		{
			{	'F',	8,	AA_GPIO_AF_9,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_9,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM13

	#if (WITH_TIM_14 == 1)
	{
		14,									// Descriptor identifier
		14,									// Timer number 1..n
		RCC_APB1RSTR_TIM14RST_Pos,			// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM14EN_Pos,			// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT2 | TIM_CAP_CHAN_1, // Capabilities flags
		TIM14,								// Pointer to TIM registers
		TIM8_TRG_COM_TIM14_IRQn,
		{
			{	'F',	9,	AA_GPIO_AF_9,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_MEDIUM },	// Ch1
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch2
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch4
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch1N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch2N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// Ch3N
			{	0,		0,	AA_GPIO_AF_9,	0 },	// ETR
			{	0,		0,	AA_GPIO_AF_9,	0 },	// BKIN
		},
	},
	#endif	// WITH_TIM14


	// Used by some aaBasic tests
	#if (WITH_TIM_2 == 1)
	{
		200,							// Descriptor identifier
		2,								// Timer number 1..14
		RCC_APB1RSTR_TIM2RST_Pos,		// RCC_APBxRSTR_TIMnRST_Pos
		RCC_APB1ENR_TIM2EN_Pos,			// RCC_APBxRSTR_TIMnEN_Pos
		TIM_CAP_TYPE_GPT1 | TIM_CAP_CHAN_1_4 | TIM_CAP_UP_DOWN | TIM_CAP_DMA | TIM_CAP_ETR | TIM_CAP_32_BITS, 	// Capabilities flags
		TIM2,							// Pointer to TIM registers
		TIM2_IRQn,
		{
			{	'A',	0,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_VERYHIGH },		// Ch1
			{	0,		3,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_HIGH },		// Ch2
			{	0,		10,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_HIGH },		// Ch3
			{	0,		3,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_HIGH },		// Ch4
			{	0,		0,	AA_GPIO_AF_1,	0 },		// Ch1N
			{	0,		0,	AA_GPIO_AF_1,	0 },		// Ch2N
			{	0,		0,	AA_GPIO_AF_1,	0 },		// Ch3N
			{	0,		15,	AA_GPIO_AF_1,	AA_GPIO_MODE_ALT_PP | AA_GPIO_SPEED_HIGH },		// ETR
			{	0,		0,	AA_GPIO_AF_1,	0 },		// BKIN
		},
	},
	#endif	// WITH_TIM2

} ;
//------------------------------------------------------------------------------
#endif	// timF4xx_H_
