/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	testmco.c		Configure MCO1/2 output for STM32H7xx

	When		Who	What
	09/04/20	ac	Creation
	16/08/21	ac	Error in configureMco() for MCO1

----------------------------------------------------------------------
*/

#include	"aa.h"
#include	"aalogmes.h"
#include	"aaprintf.h"

#include	"test.h"
#include	"gpiobasic.h"

#include	"stm32f4xx_ll_rcc.h"
#include	"stm32f4xx_ll_pwr.h"

//--------------------------------------------------------------------------------
//	Interactive selection of MCO1 / MCO2

static	uint32_t	mco1Sel ;
static	uint32_t	mco2Sel ;

static	uint32_t	mco1Div ;
static	uint32_t	mco2Div ;

//----------------------------------------------------------------------

void	configureMco (uint32_t co)
{
	uint32_t	cc ;

	if (co == '1')
	{
		// Configure MCO1 output
		gpioPinDesc_t	io = { 'A', 8, AA_GPIO_AF_0, AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_VERYHIGH | AA_GPIO_PUSH_PULL } ;

		gpioConfigurePin (& io) ;
		mco1Div = ((RCC->CFGR & RCC_CFGR_MCO1PRE) >> RCC_CFGR_MCO1PRE_Pos) ;
		if (mco1Div > 3u)
		{
			mco1Div -= 3 ;
		}
		mco1Sel = ((RCC->CFGR & RCC_CFGR_MCO1) >> RCC_CFGR_MCO1_Pos) + '0' ;

		while (1)
		{
			aaPrintf ("0   HSI\n") ;
			aaPrintf ("1   LSE\n") ;
			aaPrintf ("2   HSE\n") ;
			aaPrintf ("3   PLLCLK\n") ;
			aaPrintf ("d   Disable and quit\n") ;
			aaPrintf ("+ - Set divisor\n") ;
			aaPrintf ("q   quit\n") ;
			aaPrintf ("Select source %c / %u: ", mco1Sel, mco1Div+1) ;
			cc = aaGetChar () ;
			aaPutChar ((char) cc) ;
			aaPutChar ('\n') ;

			if (cc == 'q')
			{
				break ;
			}

			if (cc >= '0'  && cc <= '3')
			{
				mco1Sel = cc ;
				RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_MCO1) | ((cc - '0') << RCC_CFGR_MCO1_Pos) ;
			}
			else if (cc == 'd')
			{
				// Disable MCO
				gpioPinDesc_t	iod = { 'A', 8, AA_GPIO_AF_0, AA_GPIO_MODE_ANALOG } ;
				gpioConfigurePin (& iod) ;
				mco1Sel = cc ;
				break ;
			}
			else if (cc == '+')
			{
				if (mco1Div < 4)
				{
					mco1Div++ ;
					RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO1PRE) | ((mco1Div + 3) << RCC_CFGR_MCO1PRE_Pos)) ;
				}
				aaPrintf ("MCO1 divider: %u\n", mco1Div) ;
			}
			else if (cc == '-')
			{
				if (mco1Div > 0)
				{
					mco1Div-- ;
					if (mco1Div == 0)
					{
						RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO1PRE) | (mco1Div << RCC_CFGR_MCO1PRE_Pos)) ;
					}
					else
					{
						RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO1PRE) | ((mco1Div + 3) << RCC_CFGR_MCO1PRE_Pos)) ;
					}
				}
				aaPrintf ("MCO1 divider: %u\n", mco1Div) ;
			}
		}
	}
	else
	{
		// Configure MCO2 output
		gpioPinDesc_t	io = { 'C', 9, AA_GPIO_AF_0, AA_GPIO_MODE_ALTERNATE | AA_GPIO_SPEED_VERYHIGH | AA_GPIO_PUSH_PULL } ;

		gpioConfigurePin (& io) ;
		mco2Div = ((RCC->CFGR & RCC_CFGR_MCO2PRE) >> RCC_CFGR_MCO2PRE_Pos) ;
		if (mco2Div > 3u)
		{
			mco2Div -= 3 ;
		}
		mco2Sel = ((RCC->CFGR & RCC_CFGR_MCO2) >> RCC_CFGR_MCO2_Pos) + '0' ;

		while (1)
		{
			aaPrintf ("0   SYSCLK\n") ;
			aaPrintf ("1   PLLI2SPCLK\n") ;
			aaPrintf ("2   HSE\n") ;
			aaPrintf ("3   PLLCLK\n") ;
			aaPrintf ("d   Disable and quit\n") ;
			aaPrintf ("+ - Set divisor\n") ;
			aaPrintf ("q   Quit\n") ;
			aaPrintf ("Select source %c / %u: ", mco2Sel, mco2Div+1) ;
			cc = aaGetChar () ;
			aaPutChar ((char) cc) ;
			aaPutChar ('\n') ;

			if (cc == 'q')
			{
				break ;
			}

			if (cc >= '0'  && cc <= '3')
			{
				mco2Sel = cc ;
				RCC->CFGR = (RCC->CFGR & ~RCC_CFGR_MCO2) | ((cc - '0') << RCC_CFGR_MCO2_Pos) ;
			}
			else if (cc == 'd')
			{
				// Disable MCO
				gpioPinDesc_t	iod = { 'C', 9, AA_GPIO_AF_0, AA_GPIO_MODE_ANALOG } ;
				gpioConfigurePin (& iod) ;
				mco2Sel = cc ;
				break ;
			}
			else if (cc == '+')
			{
				if (mco2Div < 4)
				{
					mco2Div++ ;
					RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO2PRE) | ((mco2Div + 3) << RCC_CFGR_MCO2PRE_Pos)) ;
				}
				aaPrintf ("MCO2 divider: %u\n", mco2Div) ;
			}
			else if (cc == '-')
			{
				if (mco2Div > 0)
				{
					mco2Div-- ;
					if (mco2Div == 0)
					{
						RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO2PRE) | (mco2Div << RCC_CFGR_MCO2PRE_Pos)) ;
					}
					else
					{
						RCC->CFGR = ((RCC->CFGR & ~RCC_CFGR_MCO2PRE) | ((mco2Div + 3) << RCC_CFGR_MCO2PRE_Pos)) ;
					}
				}
				aaPrintf ("MCO2 divider: %u\n", mco2Div) ;
			}
		}
	}
}

//--------------------------------------------------------------------------------

void	mcoTest	(void)
{
	uint32_t	cc ;

	while (1)
	{
		// Configure MCO / LSCO
		aaPrintf ("Configure MCO(1) or MCO(2): ") ;
		cc = aaGetChar () ;
		aaPutChar ((char) cc) ;
		aaPutChar ('\n') ;

		if (cc == 'q')
		{
			break ;
		}

		if (cc == '1' || cc =='2')
		{
			configureMco (cc) ;
		}
		else
		{
			aaPrintf ("Unknown command\n") ;
		}
	}
	aaPrintf ("MCO test ended\n") ;
}

//--------------------------------------------------------------------------------
