/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	testrtc.c	Test RTC calendar and alarm

	When		Who	What
	04/07/21	ac	Creation

----------------------------------------------------------------------
*/
#include	"aa.h"
#include	"aaprintf.h"

#include	"test.h"
#include	"rtcbasic.h"

//--------------------------------------------------------------------------------
//	Alarm A and B callback

static	void	alarmACB (void)
{
	aaPrintf ("A\n") ;		// Dangerous to print in an interrupt handler...
}
/*
static	void	alarmBCB (void)
{
	aaPrintf ("B\n") ;		// Dangerous to print in an interrupt handler...
}
*/
//--------------------------------------------------------------------------------

void	rtcTest (void)
{
	uint32_t		cc ;
	uint32_t		ret ;
	uint32_t		backupValue = 0 ;

	// Display the state of RTC
	if (1u == rtcCheckConfig ())
	{
		aaPrintf ("RTC is configured\n") ;
	}
	else
	{
		aaPrintf ("RTC is not configured\n") ;
	}

	while (1)
	{
		cc = aaGetChar () ;
		aaPutChar ((char) cc) ;
		aaPutChar ('\n') ;

		if (cc == 'h' ||  cc == '?')
		{
			aaPrintf ("k  Check RTC configuration\n") ;
			aaPrintf ("c  Configure clocks\n") ;
			aaPrintf ("C  Configure RTC\n") ;
			aaPrintf ("d  Configure calendar\n") ;
			aaPrintf ("p  Print calendar\n") ;
			aaPrintf ("i  Print RTC_ISR\n") ;
			aaPrintf ("A  Start Alarm A\n") ;
			aaPrintf ("a  Stop Alarm A\n") ;
			aaPrintf ("w  Write backup register 5\n") ;
			aaPrintf ("r  Read and clear backup register\n") ;
			//			aaPrintf ("z  Reset RTC\n") ;
			aaPrintf ("q  Quit test\n") ;
			continue ;
		}

		if (cc == 'q')
		{
			break ;	// End of test
		}

		switch (cc)
		{
			case 'i':		// Print RTC_ISR
				aaPrintf ("ISR: %08X\n", RTC->ISR) ;
				break ;

			case 'k':		// Check RTC configuration
				ret = rtcCheckConfig () ;
				aaPrintf ("rtcCheckConfig %u (1: configured)\n", ret) ;
				break ;

			case 'c':		// Configure RTC clocks
				if (1u == rtcConfigureClocks ())
				{
					aaPrintf ("Backup domain reseted: configure RTC\n") ;
					rtcConfigure (RTC_HOUR_24, 0, 0) ;
				}
				break ;

			case 'C':		// Configure RTC
				rtcConfigure (RTC_HOUR_24, 0, 0) ;
				break ;

			case 'd':		// Configure calendar
				{
					uint32_t	time = RTC_TOTIME (17, 23, 15) ;
					uint32_t	date = RTC_TODATE (03, 07, 21) ;
					rtcSetCalendar (1, time, date) ;
				}
				break ;

			case 'p':		// Print calendar
				{
					uint32_t	wd ;
					uint32_t	time ;
					uint32_t	date ;
					rtcGetCalendar (& wd, & time, & date) ;

					aaPrintf ("RTC %02u:%02u:%02u ",
							RTC_GETHOUR (time),
							RTC_GETMIN (time),
							RTC_GETSEC (time)) ;
					aaPrintf ("%u %02u-%02u-%02u\n",
							wd,
							RTC_GETDAY (date),
							RTC_GETMONTH (date),
							RTC_GETYEAR (date)) ;

					aaPrintf ("    ") ;
					rtcPrintTime (time) ;
					aaPrintf ("   ") ;
					rtcPrintDate (date) ;
					aaPrintf ("\n") ;
				}
				break ;

			case 'z':		// De init RTC and LSE
				rtcResetBackup () ;
				break ;

			case 'A':		// Start Alarm A
				rtcAlarmSetCallback (RTC_ALARMA, alarmACB) ;
				rtcAlarmStart (0, RTC_TOSSR (6, 255), 0, RTC_ALARMA | RTC_IGNORE_WDAY | RTC_IGNORE_HOUR | RTC_IGNORE_MIN | RTC_IGNORE_SEC, BSP_IRQPRIOMIN_PLUS(1)) ;
				break ;

			case 'a':		// Stop Alarm A
				rtcAlarmStop (RTC_ALARMA) ;
				break ;

			case 'w':		// Write backup register
				rtcWriteBackupRegister (5, backupValue) ;
				backupValue++ ;
				break ;

			case 'r':		// Read and clear backup register
					aaPrintf ("Backup Register: %08X\n", rtcReadBackupRegister (5)) ;
				break ;

			default:
				break ;
		}
		if (aaCheckGetChar () != 0u)
		{
			(void) aaGetChar () ;
		}
	}

}

//--------------------------------------------------------------------------------
